---
name: Feature request
about: Suggest an idea for this project
---

<!--
  Hi there! Thank you for wanting to make pylint better.

  Before you submit this, make sure that this feature wasn't
  already requested or if it is not already implemented in the master branch.
-->

### Is your feature request related to a problem? Please describe

A clear and concise description of what the problem is.

### Describe the solution you'd like

A clear and concise description of what you want to happen.

### Additional context

Add any other context about the feature request here.
